<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation>Mover a la papelera</translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Desanclar</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Anclar</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Forzar cierre</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Cerrar todo</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Desanclar</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Muelle</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Forzar cierre</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Cerrar todo</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation>%1 archivos</translation>
    </message>
</context>
</TS>